##  SAP Signavio URL
For the SAP Signavio SaaS offering, the URL depends on the instance you're using:
  * Europe - https://editor.signavio.com
  * United States - https://app-us.signavio.com
  * Australia - https://app-au.signavio.com
  * Japan - https://app-jp.signavio.com
  * Canada - https://app-ca.signavio.com
  * Singapore - https://app-sgp.signavio.com
  * South Korea - https://app-kr.signavio.com
